@@ -5,7 +5,7 @@ use webrtc::{
 
 use serde::{Deserialize, Serialize};
 
-#[derive(Debug, Serialize, Deserialize)]
+#[derive(Debug, Serialize, Deserialize, Clone)]
 pub enum WebrtcAddr {
     #[serde(skip)]
     Bootstrap(Vec<RTCIceServer>),
